@@ -8,7 +8,7 @@ use Mojo::Util 'steady_time';
 use Sys::Hostname 'hostname';
 use Time::HiRes 'usleep';
 
-our $VERSION = '4.000';
+our $VERSION = '4.001';
 
 has dequeue_interval => 0.5;
 has 'sqlite';
@@ -62,6 +62,43 @@ sub enqueue {
 sub fail_job   { shift->_update(1, @_) }
 sub finish_job { shift->_update(0, @_) }
 
+sub history {
+  my $self = shift;
+
+  my $db = $self->sqlite->db;
+  my $steps = $db->query(
+    q{with recursive generate_series(ts) as (
+        select datetime('now','-23 hours')
+        union all
+        select datetime(ts,'+1 hour') from generate_series
+        where datetime(ts,'+1 hour') <= datetime('now')
+      ) select ts, strftime('%s',ts) as epoch,
+        strftime('%d',ts,'localtime') as day,
+        strftime('%H',ts,'localtime') as hour
+      from generate_series order by epoch})->hashes;
+
+  my $counts = $db->query(
+    q{select strftime('%d',finished,'localtime') as day,
+        strftime('%H',finished,'localtime') as hour,
+        count(case state when 'failed' then 1 end) as failed_jobs,
+        count(case state when 'finished' then 1 end) as finished_jobs
+      from minion_jobs
+      where finished > ? group by day, hour}, $steps->first->{ts})->hashes;
+
+  my %daily = map { ("$_->{day}-$_->{hour}" => $_) } @$counts;
+  my @daily_ordered;
+  foreach my $step (@$steps) {
+    my $hour_counts = $daily{"$step->{day}-$step->{hour}"} // {};
+    push @daily_ordered, {
+      epoch => $step->{epoch},
+      failed_jobs => $hour_counts->{failed_jobs} // 0,
+      finished_jobs => $hour_counts->{finished_jobs} // 0,
+    };
+  }
+
+  return {daily => \@daily_ordered};
+}
+
 sub list_jobs {
   my ($self, $offset, $limit, $options) = @_;
 
@@ -582,6 +619,25 @@ delay based on L<Minion/"backoff">.
 
 Transition from C<active> to C<finished> state.
 
+=head2 history
+
+  my $history = $backend->history;
+
+Get history information for job queue. Note that this method is EXPERIMENTAL and
+might change without warning!
+
+These fields are currently available:
+
+=over 2
+
+=item daily
+
+  daily => [{epoch => 12345, finished_jobs => 95, failed_jobs => 2}, ...]
+
+Hourly counts for processed jobs from the past day.
+
+=back
+
 =head2 list_jobs
 
   my $results = $backend->list_jobs($offset, $limit);
